TypedDataChunk

Struct TypedDataChunk 

pub struct TypedDataChunk<D: DataChunk, T: Archive> { /* private fields */ }

Implementations

Source

impl<D, T> TypedDataChunk<D, T>
where D: DataChunk, T: Archive, T::Archived: for<'a> CheckBytes<HighValidator<'a, Error>>,

pub fn from_data_chunk(chunk: D) -> Result<Self>

Builds a typed view after validating that the byte layout is a valid archived T.

This method assumes D upholds crate::DataChunk invariants (stable, immutable bytes/hash for &self) for the lifetime of this value.

pub fn typed_ref(&self) -> Result<&T::Archived>

Returns a checked typed reference.

Unlike Deref, this method always validates the underlying bytes before returning the archived value.